@@ -2,7 +2,6 @@ import click
 import sys
 
 from . import version
-# from .tctl import cli
 
 # internals
 from . import config
@@ -13,7 +12,9 @@ from . import strategies
 from . import tradehooks
 from . import monitors
 from . import orders
-# from . import admin
+from . import trading
+from . import tokens
+
 
 if "--version" in sys.argv or "-V" in sys.argv:
     click.echo("\ntctl {version}".format(version=version.version))
@@ -31,6 +32,8 @@ cli = click.CommandCollection(sources=[
     tradehooks.cli,
     monitors.cli,
     orders.cli,
+    trading.cli,
+    tokens.cli
 ])
 
 
