@@ -92,7 +92,9 @@ def account_create(options):
     auth = {}
     # key = secret = account_id = None
 
-    if broker["broker"] != "tradologics":
+    if broker["broker"] == "tradologics":
+        paper_mode = True
+    else:
         if broker.get("has_paper", False):
             paper_mode = inputs.confirm(
                 "Use broker's paper account", default=True)
