@@ -32,10 +32,16 @@ def assets_options_validator(ctx, param, args):
     elif sys.argv[1].lower() == "bars":
         COMMANDS = BARS_COMMANDS
 
-    if len(args) == 0 or args[0] not in COMMANDS:
-        cmd = [f"{k}  {v}" for k, v in COMMANDS.items()]
+    cmd = [f"{k}  {v}" for k, v in COMMANDS.items()]
+    if len(args) == 0:
+        click.echo("Usage: tctl {command} ACTION [OPTIONS]...".format(
+            command=sys.argv[1]))
+        click.echo("\nAvailable actions:\n\n - {commands}".format(
+                commands='\n - '.join(cmd)))
+        sys.exit(0)
+    if args[0] not in COMMANDS:
         raise click.UsageError(
-            "Command shoule be one of:\n\n - {commands}".format(
+            "Action shoule be one of:\n\n - {commands}".format(
                 commands='\n - '.join(cmd)))
 
     args = list(args)
