@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 
 import click
+import sys
 from .. import utils
 from . import crud
 from . import crud_versions
@@ -25,10 +26,16 @@ COMMANDS = {
 
 
 def options_validator(ctx, param, args):
-    if len(args) == 0 or args[0] not in COMMANDS:
-        cmd = [f"{k}  {v}" for k, v in COMMANDS.items()]
+    cmd = [f"{k}  {v}" for k, v in COMMANDS.items()]
+    if len(args) == 0:
+        click.echo("Usage: tctl {command} ACTION [OPTIONS]...".format(
+            command=sys.argv[1]))
+        click.echo("\nAvailable actions:\n\n - {commands}".format(
+                commands='\n - '.join(cmd)))
+        sys.exit(0)
+    if args[0] not in COMMANDS:
         raise click.UsageError(
-            "Command shoule be one of:\n\n - {commands}".format(
+            "Action shoule be one of:\n\n - {commands}".format(
                 commands='\n - '.join(cmd)))
 
     args = list(args)
