@@ -169,8 +169,8 @@ def strategy_start(options):
     if "Tradelet" in data["message"]:
         data["message"] = [
             "Tradelet deploy initialized...\n",
-            f"  - Check status using `tctl status --strategy {strategy}`",
-            f"  - Deploy log is available via `tctl log --strategy {strategy}`",
+            f"  - Check status using `tctl strategies status --strategy {strategy}`",
+            f"  - Deploy log is available via `tctl strategies log --strategy {strategy}`",
         ]
     else:
         data["message"] = ["Strategy starting.."]
@@ -225,7 +225,10 @@ def strategy_create(options):
     utils.success_response(
         f"The strategy `{name}` ({mode}) was added to your account.")
 
-    df = pd.DataFrame([data])
+    cols = ['name', 'strategy_id', 'description', 'as_tradelet', 'mode']
+    if not as_tradelet:
+        cols.append("url")
+    df = pd.DataFrame([data])[cols]
     df.columns = [col.replace("_", " ").title() for col in df.columns]
     click.echo(utils.to_table(df.T, showindex=True, showheaders=False))
 
