@@ -70,8 +70,11 @@ def strategy_deploy(options):
     # path = inputs.path("Path to code directory", validator="directory")
 
     # --- now ---
-    strategy_file = inputs.path(
-        "Path to `{file}`".format(file=STRATEGY_FILES[lang]), validator="file")
+    strategy_file_found = False
+    while not strategy_file_found:
+        strategy_file = inputs.path(
+            "Path to `{file}`".format(file=STRATEGY_FILES[lang]), validator="file")
+        strategy_file_found = Path(strategy_file).exists()
 
     path = Path(strategy_file).parents[0]
     dependencies = []
@@ -109,12 +112,10 @@ def strategy_deploy(options):
     utils.success_response(
         """Strategy code (v{version}) was deployed successfully.
 
---------------------------------------
 NOTE: If you haven't already, attach a Tradehook
 to this strategy and start your strategy using:
 
 $ tctl strategies start --strategy {strategy}
---------------------------------------
         """.format(
             strategy=strategy,
             version=data["version"]
