@@ -88,8 +88,11 @@ def tradehook_create(options, from_update=False):
         while name == "":
             name = inputs.text("Tradehook name")
 
-    config_file = inputs.path(
-        "Path to Tradehook configuration file", validator="file")
+    config_file_found = False
+    while not config_file_found:
+        config_file = inputs.path(
+            "Path to Tradehook configuration file", validator="file")
+        config_file_found = Path(config_file).exists()
 
     selected_strategies = inputs.checkboxes(
         "Attach to strategy/ies (optional, can be done later)", list(strategies.keys()))
@@ -126,10 +129,10 @@ def tradehook_create(options, from_update=False):
         return
 
     utils.success_response(
-        f"The Tradehook account `{name}` was added to your account.")
+        f"The Tradehook `{name}` was added to your account.")
     if strategies:
-        click.echo("The Tradehook was attached to:")
-    click.echo("  - "+"\n  - ".join(strategies))
+        click.echo("It was attached to:")
+        click.echo("  - "+"\n  - ".join(strategies))
 
 
 def tradehook_update(options):
